"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMintSize = exports.getMintAccountDataSerializer = exports.deserializeMint = exports.getMintGpaBuilder = exports.safeFetchAllMint = exports.fetchAllMint = exports.safeFetchMint = exports.fetchMint = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
async function fetchMint(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    (0, umi_core_1.assertAccountExists)(maybeAccount, 'Mint');
    return deserializeMint(context, maybeAccount);
}
exports.fetchMint = fetchMint;
async function safeFetchMint(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    return maybeAccount.exists ? deserializeMint(context, maybeAccount) : null;
}
exports.safeFetchMint = safeFetchMint;
async function fetchAllMint(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts.map((maybeAccount) => {
        (0, umi_core_1.assertAccountExists)(maybeAccount, 'Mint');
        return deserializeMint(context, maybeAccount);
    });
}
exports.fetchAllMint = fetchAllMint;
async function safeFetchAllMint(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts
        .filter((maybeAccount) => maybeAccount.exists)
        .map((maybeAccount) => deserializeMint(context, maybeAccount));
}
exports.safeFetchAllMint = safeFetchAllMint;
function getMintGpaBuilder(context) {
    const s = context.serializer;
    const programId = context.programs.get('splToken').publicKey;
    return (0, umi_core_1.gpaBuilder)(context, programId)
        .registerFields([
        ['mintAuthority', s.fixedOption(s.publicKey, s.u32)],
        ['supply', s.u64],
        ['decimals', s.u8],
        ['isInitialized', s.bool()],
        ['freezeAuthority', s.fixedOption(s.publicKey, s.u32)],
    ])
        .deserializeUsing((account) => deserializeMint(context, account))
        .whereSize(82);
}
exports.getMintGpaBuilder = getMintGpaBuilder;
function deserializeMint(context, rawAccount) {
    return (0, umi_core_1.deserializeAccount)(rawAccount, getMintAccountDataSerializer(context));
}
exports.deserializeMint = deserializeMint;
function getMintAccountDataSerializer(context) {
    const s = context.serializer;
    return s.struct([
        ['mintAuthority', s.fixedOption(s.publicKey, s.u32)],
        ['supply', s.u64],
        ['decimals', s.u8],
        ['isInitialized', s.bool()],
        ['freezeAuthority', s.fixedOption(s.publicKey, s.u32)],
    ], 'Mint');
}
exports.getMintAccountDataSerializer = getMintAccountDataSerializer;
function getMintSize(_context = {}) {
    return 82;
}
exports.getMintSize = getMintSize;
//# sourceMappingURL=mint.js.map