import { Account, Context, Option, PublicKey, RpcAccount, RpcGetAccountOptions, RpcGetAccountsOptions, Serializer } from '@metaplex-foundation/umi-core';
import { TokenState } from '../types';
export type Token = Account<TokenAccountData>;
export type TokenAccountData = {
    mint: PublicKey;
    owner: PublicKey;
    amount: bigint;
    delegate: Option<PublicKey>;
    state: TokenState;
    isNative: Option<bigint>;
    delegatedAmount: bigint;
    closeAuthority: Option<PublicKey>;
};
export type TokenAccountArgs = {
    mint: PublicKey;
    owner: PublicKey;
    amount: number | bigint;
    delegate: Option<PublicKey>;
    state: TokenState;
    isNative: Option<number | bigint>;
    delegatedAmount: number | bigint;
    closeAuthority: Option<PublicKey>;
};
export declare function fetchToken(context: Pick<Context, 'rpc' | 'serializer'>, publicKey: PublicKey, options?: RpcGetAccountOptions): Promise<Token>;
export declare function safeFetchToken(context: Pick<Context, 'rpc' | 'serializer'>, publicKey: PublicKey, options?: RpcGetAccountOptions): Promise<Token | null>;
export declare function fetchAllToken(context: Pick<Context, 'rpc' | 'serializer'>, publicKeys: PublicKey[], options?: RpcGetAccountsOptions): Promise<Token[]>;
export declare function safeFetchAllToken(context: Pick<Context, 'rpc' | 'serializer'>, publicKeys: PublicKey[], options?: RpcGetAccountsOptions): Promise<Token[]>;
export declare function getTokenGpaBuilder(context: Pick<Context, 'rpc' | 'serializer' | 'programs'>): import("@metaplex-foundation/umi-core").GpaBuilder<Token, {
    mint: PublicKey;
    owner: PublicKey;
    amount: number | bigint;
    delegate: Option<PublicKey>;
    state: TokenState;
    isNative: Option<number | bigint>;
    delegatedAmount: number | bigint;
    closeAuthority: Option<PublicKey>;
}>;
export declare function deserializeToken(context: Pick<Context, 'serializer'>, rawAccount: RpcAccount): Token;
export declare function getTokenAccountDataSerializer(context: Pick<Context, 'serializer'>): Serializer<TokenAccountArgs, TokenAccountData>;
export declare function getTokenSize(_context?: {}): number;
