"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAccount = exports.getCreateAccountInstructionDataSerializer = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
function getCreateAccountInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_core_1.mapSerializer)(s.struct([
        ['discriminator', s.u32],
        ['lamports', (0, umi_core_1.mapAmountSerializer)(s.u64, 'SOL', 9)],
        ['space', s.u64],
        ['programId', s.publicKey],
    ], 'CreateAccountInstructionArgs'), (value) => ({ ...value, discriminator: 0 }));
}
exports.getCreateAccountInstructionDataSerializer = getCreateAccountInstructionDataSerializer;
function createAccount(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.get('splSystem').publicKey;
    const payerAccount = input.payer ?? context.payer;
    const newAccountAccount = input.newAccount;
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(payerAccount, true),
    });
    signers.push(newAccountAccount);
    keys.push({
        pubkey: newAccountAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(newAccountAccount, true),
    });
    const data = getCreateAccountInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = Number(input.space) + umi_core_1.ACCOUNT_HEADER_SIZE;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.createAccount = createAccount;
//# sourceMappingURL=createAccount.js.map