"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createIdempotentAssociatedToken = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
function createIdempotentAssociatedToken(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.get('splAssociatedToken').publicKey;
    const payerAccount = input.payer ?? context.payer;
    const ataAccount = input.ata;
    const ownerAccount = input.owner;
    const mintAccount = input.mint;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.get('splSystem').publicKey,
        isWritable: false,
    };
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.get('splToken').publicKey,
        isWritable: false,
    };
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: ataAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(ataAccount, true),
    });
    keys.push({
        pubkey: ownerAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(ownerAccount, false),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    const data = new Uint8Array();
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.createIdempotentAssociatedToken = createIdempotentAssociatedToken;
//# sourceMappingURL=createIdempotentAssociatedToken.js.map