"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createTokenIfMissing = exports.getCreateTokenIfMissingInstructionDataSerializer = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
const hooked_1 = require("../../hooked");
function getCreateTokenIfMissingInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_core_1.mapSerializer)(s.struct([['discriminator', s.u8]], 'CreateTokenIfMissingInstructionArgs'), (value) => ({ ...value, discriminator: 0 }));
}
exports.getCreateTokenIfMissingInstructionDataSerializer = getCreateTokenIfMissingInstructionDataSerializer;
function createTokenIfMissing(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.get('mplTokenExtras').publicKey;
    const payerAccount = input.payer ?? context.payer;
    const ownerAccount = input.owner ?? context.identity.publicKey;
    const mintAccount = input.mint;
    const ataAccount = input.ata ??
        (0, hooked_1.findAssociatedTokenPda)(context, {
            owner: (0, umi_core_1.publicKey)(ownerAccount),
            mint: (0, umi_core_1.publicKey)(mintAccount),
        });
    const tokenAccount = input.token ?? ataAccount;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.get('splSystem').publicKey,
        isWritable: false,
    };
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.get('splToken').publicKey,
        isWritable: false,
    };
    const ataProgramAccount = input.ataProgram ?? {
        ...context.programs.get('splAssociatedToken').publicKey,
        isWritable: false,
    };
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: tokenAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(tokenAccount, false),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: ownerAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(ownerAccount, false),
    });
    keys.push({
        pubkey: ataAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(ataAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    keys.push({
        pubkey: ataProgramAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(ataProgramAccount, false),
    });
    const data = getCreateTokenIfMissingInstructionDataSerializer(context).serialize({});
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.createTokenIfMissing = createTokenIfMissing;
//# sourceMappingURL=createTokenIfMissing.js.map