"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mintTokensToChecked = exports.getMintTokensToCheckedInstructionDataSerializer = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
function getMintTokensToCheckedInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_core_1.mapSerializer)(s.struct([
        ['discriminator', s.u8],
        ['amount', s.u64],
        ['decimals', s.u8],
    ], 'MintTokensToCheckedInstructionArgs'), (value) => ({ ...value, discriminator: 14 }));
}
exports.getMintTokensToCheckedInstructionDataSerializer = getMintTokensToCheckedInstructionDataSerializer;
function mintTokensToChecked(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.get('splToken').publicKey;
    const mintAccount = input.mint;
    const tokenAccount = input.token;
    const mintAuthorityAccount = input.mintAuthority;
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(mintAccount, true),
    });
    keys.push({
        pubkey: tokenAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(tokenAccount, true),
    });
    signers.push(mintAuthorityAccount);
    keys.push({
        pubkey: mintAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(mintAuthorityAccount, false),
    });
    const data = getMintTokensToCheckedInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.mintTokensToChecked = mintTokensToChecked;
//# sourceMappingURL=mintTokensToChecked.js.map