"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setAuthority = exports.getSetAuthorityInstructionDataSerializer = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
const types_1 = require("../types");
function getSetAuthorityInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_core_1.mapSerializer)(s.struct([
        ['discriminator', s.u8],
        ['authorityType', (0, types_1.getAuthorityTypeSerializer)(context)],
        ['newAuthority', s.option(s.publicKey)],
    ], 'SetAuthorityInstructionArgs'), (value) => ({ ...value, discriminator: 6 }));
}
exports.getSetAuthorityInstructionDataSerializer = getSetAuthorityInstructionDataSerializer;
function setAuthority(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.get('splToken').publicKey;
    const ownedAccount = input.owned;
    const ownerAccount = input.owner;
    const signerAccount = input.signer;
    keys.push({
        pubkey: ownedAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(ownedAccount, true),
    });
    signers.push(ownerAccount);
    keys.push({
        pubkey: ownerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(ownerAccount, false),
    });
    signers.push(signerAccount);
    keys.push({
        pubkey: signerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(signerAccount, false),
    });
    const data = getSetAuthorityInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.setAuthority = setAuthority;
//# sourceMappingURL=setAuthority.js.map