"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transferSol = exports.getTransferSolInstructionDataSerializer = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
function getTransferSolInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_core_1.mapSerializer)(s.struct([
        ['discriminator', s.u32],
        ['amount', (0, umi_core_1.mapAmountSerializer)(s.u64, 'SOL', 9)],
    ], 'TransferSolInstructionArgs'), (value) => ({ ...value, discriminator: 2 }));
}
exports.getTransferSolInstructionDataSerializer = getTransferSolInstructionDataSerializer;
function transferSol(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.get('splSystem').publicKey;
    const sourceAccount = input.source ?? context.identity;
    const destinationAccount = input.destination;
    signers.push(sourceAccount);
    keys.push({
        pubkey: sourceAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(sourceAccount, true),
    });
    keys.push({
        pubkey: destinationAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(destinationAccount, true),
    });
    const data = getTransferSolInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.transferSol = transferSol;
//# sourceMappingURL=transferSol.js.map